@@ -22,13 +22,15 @@
 #include <analitza/variables.h>
 #include <analitzagui/expressionedit.h>
 
+#include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
-#include <QDialogButtonBox>
 #include <klocalizedstring.h>
 
 VarEdit::VarEdit(QWidget *parent, bool modal)
-    : QDialog(parent), vars(nullptr), m_correct(false)
+    : QDialog(parent)
+    , vars(nullptr)
+    , m_correct(false)
 {
     setWindowTitle(i18n("Add/Edit a variable"));
     setModal(modal);
@@ -37,31 +39,31 @@ VarEdit::VarEdit(QWidget *parent, bool modal)
     m_buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     m_removeBtn = m_buttonBox->addButton(i18n("Remove Variable"), QDialogButtonBox::DestructiveRole);
     m_removeBtn->setIcon(QIcon::fromTheme(QStringLiteral("edit-table-delete-row")));
-    
+
     connect(m_removeBtn, &QAbstractButton::clicked, this, &VarEdit::removeVariable);
-    
-    connect( m_buttonBox, &QDialogButtonBox::accepted, this, &VarEdit::accept );
-    connect( m_buttonBox, &QDialogButtonBox::rejected, this, &VarEdit::reject );
-    
+
+    connect(m_buttonBox, &QDialogButtonBox::accepted, this, &VarEdit::accept);
+    connect(m_buttonBox, &QDialogButtonBox::rejected, this, &VarEdit::reject);
+
     m_exp = new Analitza::ExpressionEdit(this);
     connect(m_exp, &QPlainTextEdit::textChanged, this, &VarEdit::edit);
     connect(m_exp, &Analitza::ExpressionEdit::returnPressed, this, &VarEdit::ok);
-    
+
     m_valid = new QLabel(this);
-    
+
     QVBoxLayout *topLayout = new QVBoxLayout(this);
     topLayout->addWidget(m_exp);
     topLayout->addWidget(m_valid);
     topLayout->addWidget(m_buttonBox);
-    
+
     m_exp->setFocus();
 }
 
-void VarEdit::setName(const QString& newVar)
+void VarEdit::setName(const QString &newVar)
 {
-    m_var=newVar;
+    m_var = newVar;
     setWindowTitle(i18n("Edit '%1' value", newVar));
-    if(!vars)
+    if (!vars)
         m_exp->setText(i18n("not available"));
     else {
         m_exp->setExpression(Analitza::Expression(vars->value(newVar)->copy()));
@@ -69,12 +71,12 @@ void VarEdit::setName(const QString& newVar)
     m_removeBtn->setEnabled(vars && canRemove(newVar));
 }
 
-bool VarEdit::canRemove(const QString& name) const
+bool VarEdit::canRemove(const QString &name) const
 {
-    QHash<QString, Analitza::Object*>::const_iterator it = vars->constBegin(), itEnd = vars->constEnd();
-    for(; it!=itEnd; ++it) {
+    QHash<QString, Analitza::Object *>::const_iterator it = vars->constBegin(), itEnd = vars->constEnd();
+    for (; it != itEnd; ++it) {
         QStringList deps = AnalitzaUtils::dependencies(*it, QStringList());
-        if(deps.contains(name)) {
+        if (deps.contains(name)) {
             return false;
         }
     }
@@ -85,16 +87,16 @@ Analitza::Expression VarEdit::val()
 {
     Analitza::Expression val;
     Analitza::Analyzer a(vars);
-    
+
     a.setExpression(m_exp->expression());
-    
-    if(a.isCorrect()) {
+
+    if (a.isCorrect()) {
         a.simplify();
-        val=a.expression();
+        val = a.expression();
     }
-    
+
     m_correct = a.isCorrect();
-    if(m_correct) {
+    if (m_correct) {
         m_valid->setText(i18n("<b style='color:#090'>%1 := %2</b>", m_var, val.toString()));
         m_valid->setToolTip(QString());
     } else {
@@ -103,7 +105,7 @@ Analitza::Expression VarEdit::val()
     }
     m_buttonBox->button(QDialogButtonBox::Ok)->setEnabled(m_correct);
     m_exp->setCorrect(m_correct);
-    
+
     return val;
 }
 
@@ -114,13 +116,13 @@ void VarEdit::edit()
 
 void VarEdit::ok()
 {
-    if(m_correct)
+    if (m_correct)
         accept();
 }
 
-void VarEdit::setAnalitza(Analitza::Analyzer * na)
+void VarEdit::setAnalitza(Analitza::Analyzer *na)
 {
-    vars= na->variables();
+    vars = na->variables();
     m_exp->setAnalitza(na);
 }
 
